/*	$NetBSD: d_constant_conv1.c,v 1.4 2022/01/15 14:22:03 rillig Exp $	*/
# 3 "d_constant_conv1.c"

/* Flag information-losing constant conversion in argument lists */

int f(unsigned int);

void
should_fail()
{
	/* expect+1: warning: conversion of negative constant to unsigned type, arg #1 [296] */
	f(-1);
}
